@@ -7,7 +7,7 @@ from collections import Counter
 
 import tensorflow as tf
 
-from ..vocab import Vocab
+from sknlp.vocab import Vocab
 
 
 class BaseNLPModel:
@@ -16,11 +16,15 @@ class BaseNLPModel:
         self,
         max_sequence_length: Optional[int] = None,
         sequence_length: Optional[int] = None,
-        name: Optional[str] = None
+        segmenter: Optional[str] = None,
+        name: Optional[str] = None,
+        **kwargs
     ) -> None:
         self._max_sequence_length = max_sequence_length
         self._sequence_length = sequence_length
+        self._segmenter = segmenter
         self._name = name
+        self._kwargs = kwargs
         self._built = False
 
     @property
@@ -31,6 +35,10 @@ class BaseNLPModel:
     def sequence_length(self) -> Optional[int]:
         return self._sequence_length
 
+    @property
+    def segmenter(self) -> Optional[str]:
+        return self._segmenter
+
     @staticmethod
     def build_vocab(
         texts: Sequence[str],
@@ -119,11 +127,12 @@ class BaseNLPModel:
         return {
             "max_sequence_length": self.max_sequence_length,
             "sequence_length": self.sequence_length,
+            "segmenter": self.segmenter,
             "name": self._name
         }
 
     @classmethod
-    def _filter_config(cls, config) -> Dict[str, Any]:
+    def _filter_config(cls, config: Dict[str, Any]) -> Dict[str, Any]:
         return config
 
     @classmethod
