@@ -7,8 +7,7 @@ import tensorflow as tf
 
 from sknlp.vocab import Vocab
 from sknlp.data import ClassificationDataset
-from sknlp.metrics import PrecisionWithLogits, RecallWithLogits
-from sknlp.callbacks import FScore
+from sknlp.metrics import PrecisionWithLogits, RecallWithLogits, FBetaScoreWithLogits
 
 from ..supervised_model import SupervisedNLPModel
 from ..text2vec import Text2vec
@@ -31,6 +30,8 @@ class DeepClassifier(SupervisedNLPModel):
     ):
         classes = list(classes)
         if not is_multilabel and "NULL" != classes[0]:
+            if "NULL" in classes:
+                classes.remove("NULL")
             classes.insert(0, "NULL")
         super().__init__(
             classes,
@@ -45,26 +46,35 @@ class DeepClassifier(SupervisedNLPModel):
         self._is_multilabel = is_multilabel
         self._loss = loss
 
+    @property
+    def is_multilabel(self):
+        return self._is_multilabel
+
     def get_loss(self):
-        if self._is_multilabel:
+        if self.is_multilabel:
             return tf.keras.losses.BinaryCrossentropy(from_logits=True)
         else:
             return tf.keras.losses.CategoricalCrossentropy(from_logits=True)
 
     def get_callbacks(self) -> List[tf.keras.callbacks.Callback]:
-        return [FScore()]
+        return []
 
     def get_metrics(self) -> List[tf.keras.metrics.Metric]:
-        if self._is_multilabel:
-            return [PrecisionWithLogits(), RecallWithLogits()]
+        if self.is_multilabel:
+            return [
+                PrecisionWithLogits(),
+                RecallWithLogits(),
+                FBetaScoreWithLogits(self.num_classes),
+            ]
         else:
             return [
                 PrecisionWithLogits(logits2scores="softmax"),
                 RecallWithLogits(logits2scores="softmax"),
+                FBetaScoreWithLogits(self.num_classes, logits2scores="softmax"),
             ]
 
     def get_monitor(self) -> str:
-        return "val_f-score"
+        return "val_fbeta_score"
 
     def create_dataset_from_df(
         self, df: pd.DataFrame, vocab: Vocab, segmenter: str, labels: Sequence[str]
@@ -73,8 +83,8 @@ class DeepClassifier(SupervisedNLPModel):
             vocab,
             list(labels),
             df=df,
-            is_multilabel=self._is_multilabel,
-            max_length=self._max_sequence_length,
+            is_multilabel=self.is_multilabel,
+            max_length=self.max_sequence_length,
             text_segmenter=segmenter,
         )
 
@@ -89,7 +99,7 @@ class DeepClassifier(SupervisedNLPModel):
         batch_size: int = 128
     ) -> np.ndarray:
         logits = super().predict(X=X, dataset=dataset, batch_size=batch_size)
-        return logits2probabilities(logits, self._is_multilabel)
+        return logits2probabilities(logits, self.is_multilabel)
 
     def predict(
         self,
@@ -101,29 +111,26 @@ class DeepClassifier(SupervisedNLPModel):
     ) -> Union[List[str], List[List[str]]]:
         probabilities = self.predict_proba(X=X, dataset=dataset, batch_size=batch_size)
         predictions = probabilities2classes(
-            probabilities, self._is_multilabel, thresholds=thresholds
+            probabilities, self.is_multilabel, thresholds=thresholds
         )
-        if self._is_multilabel:
+        if self.is_multilabel:
             return [
-                [self._idx2class[i] for i in prediction] for prediction in predictions
+                [self.idx2class(i) for i in prediction] for prediction in predictions
             ]
         else:
-            return [self._idx2class[i] for i in predictions]
+            return [self.idx2class(i) for i in predictions]
 
     def score(
         self,
         X: Sequence[str] = None,
         y: Union[Sequence[Sequence[str]], Sequence[str]] = None,
         *,
-        dataset: ClassificationDataset = None,
         thresholds: Union[float, List[float]] = 0.5,
         batch_size: int = 128
     ) -> pd.DataFrame:
-        predictions = self.predict(
-            X=X, dataset=dataset, thresholds=thresholds, batch_size=batch_size
-        )
+        predictions = self.predict(X=X, thresholds=thresholds, batch_size=batch_size)
         return classification_fscore(
-            y, predictions, self._is_multilabel, classes=list(self._class2idx.keys())
+            y, predictions, self.is_multilabel, classes=self.classes
         )
 
     def format_score(self, score_df: pd.DataFrame, format: str = "markdown") -> str:
@@ -144,4 +151,5 @@ class DeepClassifier(SupervisedNLPModel):
             **super().get_custom_objects(),
             "PrecisionWithLogits": PrecisionWithLogits,
             "RecallWithLogits": RecallWithLogits,
+            "FBetaScoreWithLogits": FBetaScoreWithLogits,
         }
