@@ -4,7 +4,6 @@ import tensorflow as tf
 import tensorflow.keras.backend as K
 from tensorflow.keras.layers import Dropout
 import pandas as pd
-from tensorflow.python.ops.array_ops import sequence_mask
 
 from sknlp.layers import (
     MLPLayer,
@@ -15,7 +14,7 @@ from sknlp.layers import (
 )
 from sknlp.vocab import Vocab
 from sknlp.data import BertTaggingDataset
-from ..text2vec import Bert2vec
+from sknlp.module.text2vec import Bert2vec
 from .deep_tagger import DeepTagger
 
 
@@ -35,7 +34,7 @@ class BertTagger(DeepTagger):
         super().__init__(
             classes,
             segmenter=segmenter,
-            algorithm="bert_tagger",
+            algorithm="bert",
             embedding_size=embedding_size,
             max_sequence_length=max_sequence_length,
             start_tag="[CLS]",
@@ -43,22 +42,13 @@ class BertTagger(DeepTagger):
             text2vec=text2vec,
             **kwargs
         )
-        if self._text2vec is not None:
-            self.preprocessing_layer = BertCharPreprocessingLayer(
-                self._text2vec.vocab.sorted_tokens
-            )
-        self.mlp_layer = MLPLayer(
-            num_fc_layers,
-            hidden_size=fc_hidden_size,
-            output_size=self.num_classes,
-            name="mlp",
-        )
-        self.crf_layer = CrfLossLayer(self.num_classes)
+        self.num_fc_layers = num_fc_layers
+        self.fc_hidden_size = fc_hidden_size
+        self.output_dropout = output_dropout
         self.inputs = [
             tf.keras.Input(shape=(), dtype=tf.string, name="text_input"),
             tf.keras.Input(shape=(None,), dtype=tf.int32, name="tag_id"),
         ]
-        self._output_dropout = output_dropout
 
     def create_dataset_from_df(
         self, df: pd.DataFrame, vocab: Vocab, segmenter: str, labels: Sequence[str]
@@ -67,7 +57,7 @@ class BertTagger(DeepTagger):
             vocab,
             list(labels),
             df=df,
-            max_length=self._max_sequence_length,
+            max_length=self.max_sequence_length,
         )
 
     def get_inputs(self) -> tf.Tensor:
@@ -78,42 +68,46 @@ class BertTagger(DeepTagger):
 
     def build_encode_layer(self, inputs: tf.Tensor) -> tf.Tensor:
         texts, tag_ids = inputs
-        token_ids = self.preprocessing_layer(texts)
-        masks = tf.keras.layers.Lambda(
-            lambda x: K.cast(K.not_equal(K.cast(x, tf.int32), 0), tf.int64),
-            name="mask_layer",
-        )(token_ids)
-        embeddings, _ = self._text2vec(
-            [token_ids, K.zeros_like(token_ids, dtype=tf.int64), masks]
+        token_ids = BertCharPreprocessingLayer(self.text2vec.vocab.sorted_tokens)(texts)
+        embeddings, mask, _ = self.text2vec(
+            [token_ids, K.zeros_like(token_ids, dtype=tf.int64)]
         )
-        if self._output_dropout:
+        mask = tf.keras.layers.Lambda(
+            lambda x: tf.cast(x, tf.int32), name="mask_layer"
+        )(mask)
+        if self.output_dropout:
             noise_shape = (None, 1, self.embedding_size)
             embeddings = Dropout(
-                self._output_dropout,
+                self.output_dropout,
                 noise_shape=noise_shape,
                 name="embedding_dropout",
             )(embeddings)
-        return embeddings, masks, tag_ids
+        return embeddings, mask, tag_ids
 
     def build_output_layer(self, inputs: tf.Tensor) -> tf.Tensor:
-        embeddings, masks, tag_ids = inputs
-        emissions = self.mlp_layer(embeddings)
-        return self.crf_layer([emissions, masks, tag_ids])
+        embeddings, mask, tag_ids = inputs
+        emissions = MLPLayer(
+            self.num_fc_layers,
+            hidden_size=self.fc_hidden_size,
+            output_size=self.num_classes,
+            name="mlp",
+        )(embeddings)
+        return CrfLossLayer(self.num_classes)([emissions, tag_ids], mask)
 
     @classmethod
-    def _filter_config(cls, config):
+    def _filter_config(cls, config: Dict[str, Any]) -> Dict[str, Any]:
         config = super()._filter_config(config)
         config.pop("start_tag", None)
         config.pop("end_tag", None)
         return config
 
     def export(self, directory: str, name: str, version: str = "0") -> None:
+        mask = self._model.get_layer("mask_layer").output
         emissions = self._model.get_layer("mlp").output
-        masks = self._model.get_layer("mask_layer").output
-        crf = CrfDecodeLayer(self.num_classes, self._max_sequence_length)
+        crf = CrfDecodeLayer(self.num_classes, self.max_sequence_length)
         crf.set_weights(self._model.get_layer("crf").get_weights())
         model = tf.keras.Model(
-            inputs=self._model.inputs[0], outputs=crf([emissions, masks])
+            inputs=self._model.inputs[0], outputs=crf(emissions, mask)
         )
         original_model = self._model
         self._model = model
@@ -121,7 +115,7 @@ class BertTagger(DeepTagger):
         self._model = original_model
 
     def get_config(self) -> Dict[str, Any]:
-        return {**super().get_config(), "output_dropout": self._output_dropout}
+        return {**super().get_config(), "output_dropout": self.output_dropout}
 
     def get_custom_objects(self) -> Dict[str, Any]:
         return {
